@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-__version__ = "1.12.2"
+__version__ = "1.13.0"
 
 
 import asyncio
@@ -19,6 +19,9 @@ from bleak.exc import BleakDBusError
 
 IS_LINUX = CAN_CACHE_SERVICES = platform.system() == "Linux"
 
+if IS_LINUX:
+    from .dbus import disconnect_device
+
 if CAN_CACHE_SERVICES:
     with contextlib.suppress(ImportError):  # pragma: no cover
         from bleak.backends.bluezdbus import defs  # pragma: no cover
@@ -43,6 +46,8 @@ RSSI_SWITCH_THRESHOLD = 6
 
 __all__ = [
     "establish_connection",
+    "close_stale_connections",
+    "get_device",
     "BleakClientWithServiceCache",
     "BleakAbortedError",
     "BleakNotFoundError",
@@ -233,10 +238,14 @@ async def get_device(address: str) -> BLEDevice | None:
     """Get the device."""
     if not IS_LINUX:
         return None
-    return await get_bluez_device(address_to_bluez_path(address))
+    return await get_bluez_device(
+        address_to_bluez_path(address), _log_disappearance=False
+    )
 
 
-async def get_bluez_device(path: str, rssi: int | None = None) -> BLEDevice | None:
+async def get_bluez_device(
+    path: str, rssi: int | None = None, _log_disappearance: bool = True
+) -> BLEDevice | None:
     """Get a BLEDevice object for a BlueZ DBus path."""
     best_path = device_path = path
     rssi_to_beat = device_rssi = rssi or UNREACHABLE_RSSI
@@ -250,7 +259,8 @@ async def get_bluez_device(path: str, rssi: int | None = None) -> BLEDevice | No
         ):
             # device has disappeared so take
             # anything over the current path
-            _LOGGER.debug("Device %s has disappeared", device_path)
+            if _log_disappearance:
+                _LOGGER.debug("Device %s has disappeared", device_path)
             rssi_to_beat = device_rssi = UNREACHABLE_RSSI
 
         for path in _get_possible_paths(device_path):
@@ -291,6 +301,27 @@ async def get_bluez_device(path: str, rssi: int | None = None) -> BLEDevice | No
     return None
 
 
+async def device_is_connected(device: BLEDevice) -> bool:
+    """Check if the device is connected."""
+    if not isinstance(device.details, dict) or "path" not in device.details:
+        return False
+    try:
+        manager = await get_global_bluez_manager()
+        properties = manager._properties
+        path = device.details["path"]
+        return bool(properties[path][defs.DEVICE_INTERFACE].get("Connected"))
+    except Exception:  # pylint: disable=broad-except
+        return False
+
+
+async def close_stale_connections(device: BLEDevice) -> None:
+    """Close stale connections."""
+    if IS_LINUX and await device_is_connected(device):
+        description = ble_device_description(device)
+        _LOGGER.debug("%s - %s: Unexpectedly connected", device.name, description)
+        await disconnect_device(device)
+
+
 async def establish_connection(
     client_class: type[BleakClient],
     device: BLEDevice,
@@ -370,6 +401,10 @@ async def establish_connection(
                 client.set_cached_services(cached_services)
             create_client = False
 
+        if IS_LINUX and await device_is_connected(device):
+            _LOGGER.debug("%s - %s: Unexpectedly connected", name, description)
+            await disconnect_device(device)
+
         try:
             async with async_timeout.timeout(BLEAK_SAFETY_TIMEOUT):
                 await client.connect(
